summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2013-09-29 14:43:18 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2013-11-06 21:19:01 -0600
commit13e8c75eb09dd0cecdeb3c004df1ad7b629429ca (patch)
tree14b6698bd1f08b6134b12fa943a847c8abd8926e
parentbf4548790b0ab1325358323feeec33f07f782160 (diff)
downloadlibpng-13e8c75eb09dd0cecdeb3c004df1ad7b629429ca.tar.gz
Imported from pngcrush-1.7.69.tarv1.7.69
-rw-r--r--ChangeLog.html64
-rw-r--r--png.c6
-rw-r--r--png.h22
-rw-r--r--pngconf.h2
-rw-r--r--pngcrush.c21
-rw-r--r--pngcrush.h2
-rw-r--r--pnglibconf.h4
-rw-r--r--pngrtran.c2
-rw-r--r--pngrutil.c2
9 files changed, 92 insertions, 33 deletions
diff --git a/ChangeLog.html b/ChangeLog.html
index d3b2b6f09..3b70dc968 100644
--- a/ChangeLog.html
+++ b/ChangeLog.html
@@ -3,6 +3,70 @@
Change log:
+Version 1.7.69 (built with libpng-1.6.6 and zlib-1.2.8)
+
+Version 1.7.68 (built with libpng-1.6.4 and zlib-1.2.8)
+ Check for NULL return from malloc().
+ Undefine CLOCKS_PER_SECOND "1000" found in some version of MinGW.
+ Replaced most "atoi(argv[++i])" with "pngcrush_get_long" which does
+ "BUMP_I; strtol(argv[i],ptr,10)" and added pngcrush_check_long macro
+ to detect malformed or missing parameters (debian bug 716149).
+ Added global_things_have_changed=1 when reading -bkgd.
+ The "-bit_depth N" option did not work reliably and has been removed.
+
+Version 1.7.67 (built with libpng-1.5.17 and zlib-1.2.8)
+ Fixed handling of "-text" and "-ztext" options for text input. They had been
+ reduced to "-t" and "-z" with an incorrect argument (3 instead of 2) in
+ version 1.7.62. Bug report and patch from Tsukasa Oi.
+
+Version 1.7.66 (built with libpng-1.5.17 and zlib-1.2.8)
+ Revised pngcrush_examine_pixels_fn() to fix some incorrect reductions.
+
+Version 1.7.65 (built with libpng-1.5.17 and zlib-1.2.8)
+ Do not allow any colortype or depth reductions if acTL is present.
+ Added warnings to explain why any requested reductions were not allowed.
+
+Version 1.7.64 (built with libpng-1.5.17 and zlib-1.2.8)
+
+Version 1.7.63 (built with libpng-1.5.16 and zlib-1.2.8)
+ Add "int dowildcard=-1;" in an attempt to get wildcard arguments working
+ in the cross-compiled MinGW executables.
+
+Version 1.7.62 (built with libpng-1.5.16 and zlib-1.2.8)
+ Remove old filename before renaming, when using the "-ow" option on
+ any Windows platform, not just CYGWIN (see log entry for pngcrush-1.7.43).
+ Reverted error with handling single-character options like "-v", introduced
+ in 1.7.61.
+
+Version 1.7.61 (built with libpng-1.5.16 and zlib-1.2.8)
+ Check sBIT chunk data to see if reduction to gray or to 8-bit is permitted,
+ i.e., the RGB sBIT values are equal to each other or the sBIT values are
+ not greater than 8, respectively.
+ Do not try to make_opaque if the tRNS chunk is found.
+ Added warning when ignoring an invalid commandline option.
+ Improved brute_force handling with specified level, filter, or strategy.
+
+Version 1.7.60 (built with libpng-1.5.16 and zlib-1.2.8)
+ Revise -reduce so reducing from color-type 6 to grayscale works.
+ Issue a warning if reducing bit depth or color type would violate various
+ chunk dependencies, and do not perform the action:
+ Do not reduce to grayscale if a color bKGD chunk, sBIT or iCCP chunk
+ is present.
+ Do not reduce bit depth if bKGD or sBIT chunk is present.
+ Do not reduce palette length if the hIST chunk is present.
+ Set "found_iCCP" flag to zero to avoid re-reading a bad iCCP chunk.
+
+Version 1.7.59 (built with libpng-1.5.16 and zlib-1.2.8)
+ Show the acTL chunk in the chunk list in verbose output.
+ Fixed several bugs reported by pornel at users.sf.net:
+ Do not call png_set_benign_errors when PNG_BENIGN_ERRORS_SUPPORTED
+ is not defined
+ Renamed PNG_UNUSED() macro PNGCRUSH_UNUSED().
+ Moved a closing bracket inside the PNGCRUSH_LOCO block.
+ Moved the declaration of "new_mng" outside a PNGCRUSH_LOCO block.
+ Put reference to "input_format" inside a PNGCRUSH_LOCO block.
+ Moved declarations of mng_out and mngname inside a PNGCRUSH_LOGO block.
+
Version 1.7.58 (built with libpng-1.5.15 and zlib-1.2.7-1)
Do not enable reduce_palette by default for "-reduce", "-new", or "-old".
It still is failing for some files.
diff --git a/png.c b/png.c
index 09d671c69..050039548 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_4 Your_png_h_is_not_version_1_6_4;
+typedef png_libpng_version_1_6_6 Your_png_h_is_not_version_1_6_6;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -768,13 +768,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.4 - September 12, 2013" PNG_STRING_NEWLINE \
+ "libpng version 1.6.6 - September 16, 2013" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2013 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.4 - September 12, 2013\
+ return "libpng version 1.6.6 - September 16, 2013\
Copyright (c) 1998-2013 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 73da68417..0b7393d5a 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.4 - September 12, 2013
+ * libpng version 1.6.6 - September 16, 2013
*
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngcrush.c b/pngcrush.c
index 2c2641ef9..0da00bcd3 100644
--- a/pngcrush.c
+++ b/pngcrush.c
@@ -308,6 +308,8 @@
Change log:
+Version 1.7.69 (built with libpng-1.6.6 and zlib-1.2.8)
+
Version 1.7.68 (built with libpng-1.6.4 and zlib-1.2.8)
Check for NULL return from malloc().
Undefine CLOCKS_PER_SECOND "1000" found in some version of MinGW.
@@ -3343,12 +3345,11 @@ int main(int argc, char *argv[])
for (c = 0; c < nzeroes; c++)
*n++ = '0';
*n = '\0';
- specified_gamma = pngcrush_get_long;
- pngcrush_check_long;
+ specified_gamma = strtol(number,&endptr,10);
#else
specified_gamma = strtof(argv[i],&endptr);
- pngcrush_check_long;
#endif
+ pngcrush_check_long;
}
}
@@ -3561,12 +3562,11 @@ int main(int argc, char *argv[])
for (c = 0; c < nzeroes; c++)
*n++ = '0';
*n = '\0';
- force_specified_gamma = pngcrush_get_long;
- pngcrush_check_long;
+ force_specified_gamma = strtol(number,&endptr,10);
#else
force_specified_gamma = strtof(argv[i],&endptr);
- pngcrush_check_long;
#endif
+ pngcrush_check_long;
}
global_things_have_changed = 1;
}
@@ -4628,11 +4628,8 @@ int main(int argc, char *argv[])
if (last_trial == 0)
{
png_set_keep_unknown_chunks(read_ptr,
-#if PNG_LIBPNG_VER < 10700
- PNG_HANDLE_CHUNK_IF_SAFE, (png_bytep) NULL, 0);
-#else
PNG_HANDLE_CHUNK_NEVER, (png_bytep) NULL, 0);
-#endif
+
png_set_keep_unknown_chunks(read_ptr,
PNG_HANDLE_CHUNK_NEVER, chunks_to_ignore,
sizeof (chunks_to_ignore)/5);
@@ -4787,11 +4784,7 @@ int main(int argc, char *argv[])
0);
else
png_set_keep_unknown_chunks(write_ptr,
-#if PNG_LIBPNG_VER < 10700
- PNG_HANDLE_CHUNK_IF_SAFE,
-#else
PNG_HANDLE_CHUNK_NEVER,
-#endif
(png_bytep) NULL,
0);
diff --git a/pngcrush.h b/pngcrush.h
index a2d0dac52..7af2373bd 100644
--- a/pngcrush.h
+++ b/pngcrush.h
@@ -5,7 +5,7 @@
* license (see LICENSE, in pngcrush.c).
*/
-/* Special defines for pngcrush version 1.7.68 */
+/* Special defines for pngcrush version 1.7.69 */
#ifndef PNGCRUSH_H
#define PNGCRUSH_H
diff --git a/pnglibconf.h b/pnglibconf.h
index b26eeee50..e31ff3dec 100644
--- a/pnglibconf.h
+++ b/pnglibconf.h
@@ -1,8 +1,8 @@
-/* libpng 1.6.4 STANDARD API DEFINITION */
+/* libpng 1.6.6 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.4 - September 12, 2013 */
+/* Libpng version 1.6.6 - September 16, 2013 */
/* Copyright (c) 1998-2013 Glenn Randers-Pehrson */
diff --git a/pngrtran.c b/pngrtran.c
index bc9be39fb..5c6bbd316 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
/* pngrtran.c - transforms the data in a row for PNG readers
*
- * Last changed in libpng 1.6.4 [September 12, 2013]
+ * Last changed in libpng 1.6.4 [September 16, 2013]
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrutil.c b/pngrutil.c
index 587feb8a4..a0d324f5a 100644
--- a/pngrutil.c
+++ b/pngrutil.c
@@ -1,7 +1,7 @@
/* pngrutil.c - utilities to read a PNG file
*
- * Last changed in libpng 1.6.4 [September 12, 2013]
+ * Last changed in libpng 1.6.4 [September 16, 2013]
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/png.h b/png.h
index 229769e0b..71c2ab675 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.4 - September 12, 2013
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.4 - September 12, 2013: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -181,6 +181,8 @@
* 1.6.4beta01-02 16 10604 16.so.16.4[.0]
* 1.6.4rc01 16 10604 16.so.16.4[.0]
* 1.6.4 16 10604 16.so.16.4[.0]
+ * 1.6.5 16 10605 16.so.16.5[.0]
+ * 1.6.6 16 10606 16.so.16.6[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -212,7 +214,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.4, September 12, 2013, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -324,13 +326,13 @@
* Y2K compliance in libpng:
* =========================
*
- * September 12, 2013
+ * September 16, 2013
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.4 are Y2K compliant. It is my belief that
+ * upward through 1.6.6 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -390,9 +392,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.4"
+#define PNG_LIBPNG_VER_STRING "1.6.6"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.4 - September 12, 2013\n"
+ " libpng version 1.6.6 - September 16, 2013\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -400,7 +402,7 @@
/* These should match the first 3 components of PNG_LIBPNG_VER_STRING: */
#define PNG_LIBPNG_VER_MAJOR 1
#define PNG_LIBPNG_VER_MINOR 6
-#define PNG_LIBPNG_VER_RELEASE 4
+#define PNG_LIBPNG_VER_RELEASE 6
/* This should match the numeric part of the final component of
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
@@ -431,7 +433,7 @@
* version 1.0.0 was mis-numbered 100 instead of 10000). From
* version 1.0.1 it's xxyyzz, where x=major, y=minor, z=release
*/
-#define PNG_LIBPNG_VER 10604 /* 1.6.4 */
+#define PNG_LIBPNG_VER 10606 /* 1.6.6 */
/* Library configuration: these options cannot be changed after
* the library has been built.
@@ -536,7 +538,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_4;
+typedef char* png_libpng_version_1_6_6;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.4 - September 12, 2013
+ * libpng version 1.6.6 - September 16, 2013
* Copyright (c) 1998-2013 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.4 - September 12, 2013: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.6 - September 16, 2013: Glenn
* See also "Contributing Authors", below.
*
@@ -212,7 +214,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.4, September 12, 2013, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.6, September 16, 2013, are
* Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5